package com.citygis.web.controller;


import com.citygis.common.annotation.Log;
import com.citygis.common.core.controller.BaseController;
import com.citygis.common.core.domain.AjaxResult;
import com.citygis.common.core.page.TableDataInfo;
import com.citygis.common.enums.BusinessType;
import com.citygis.web.domain.SysWarningChannel;
import com.citygis.web.service.ISysWarningChannelService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;

/**
 * <p>
 * 告警渠道表 前端控制器
 * </p>
 *
 * @author citygis
 * @since 2025-03-13
 */
@Api(tags = "告警配置-告警渠道")
@RestController
@RequestMapping("/web/sys-warning-channel")
public class SysWarningChannelController extends BaseController {

    @Resource
    ISysWarningChannelService warningChannelService;

    @Log(title = "告警渠道列表", businessType = BusinessType.SELECT)
    @ApiOperation("告警渠道列表")
    @GetMapping("/getSysWarningChannelList")
    public TableDataInfo getSysWarningChannelList(SysWarningChannel sysWarningChannel) {
        startPage();
        return getDataTable(warningChannelService.getSysWarningChannelList(sysWarningChannel));
    }

    @Log(title = "告警渠道详情", businessType = BusinessType.SELECT)
    @ApiOperation("告警渠道详情")
    @GetMapping("/getSysWarningChannelDetailById/{id}")
    public SysWarningChannel getSysWarningChannelDetailById(@PathVariable Long id) {
        return warningChannelService.getById(id);
    }

    @Log(title = "新增告警渠道", businessType = BusinessType.INSERT)
    @ApiOperation("新增告警渠道")
    @PostMapping("/addSysWarningChannel")
    public AjaxResult addSysWarningChannel(@Validated @RequestBody SysWarningChannel sysWarningChannel) {
        return warningChannelService.addSysWarningChannel(sysWarningChannel);
    }

    @Log(title = "修改告警渠道", businessType = BusinessType.UPDATE)
    @ApiOperation("修改告警渠道")
    @PutMapping("/updateSysWarningChannelById")
    public AjaxResult updateSysWarningChannelById(@RequestBody SysWarningChannel sysWarningChannel) {
        return warningChannelService.updateSysWarningChannelById(sysWarningChannel);
    }

    @Log(title = "逻辑删除告警渠道", businessType = BusinessType.DELETE)
    @ApiOperation("逻辑删除告警渠道")
    @PutMapping("/falseDeleteSysWarningChannelById/{id}")
    public AjaxResult falseDeleteSysWarningChannelById(@PathVariable Long id) {
        return warningChannelService.falseDeleteSysWarningChannelById(id);
    }

}

