package com.citygis.web.controller;


import com.citygis.common.annotation.Log;
import com.citygis.common.core.controller.BaseController;
import com.citygis.common.core.domain.AjaxResult;
import com.citygis.common.core.page.TableDataInfo;
import com.citygis.common.enums.BusinessType;
import com.citygis.common.exception.job.TaskException;
import com.citygis.common.utils.poi.ExcelUtil;
import com.citygis.quartz.domain.SysJob;
import com.citygis.web.domain.SysWarningCheckInstance;
import com.citygis.web.service.ISysWarningCheckInstanceService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.quartz.SchedulerException;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.net.URLEncoder;
import java.util.List;

/**
 * <p>
 * 告警检查项实例表 前端控制器
 * </p>
 *
 * @author citygis
 * @since 2025-03-13
 */
@Api(tags = "告警配置-告警检查项实例")
@RestController
@RequestMapping("/web/sys-warning-check-instance")
public class SysWarningCheckInstanceController extends BaseController {

    @Resource
    ISysWarningCheckInstanceService warningCheckInstanceService;

    @Log(title = "告警检查项实例列表", businessType = BusinessType.SELECT)
    @ApiOperation("告警检查项实例列表")
    @GetMapping("/getSysWarningCheckInstanceList")
    public TableDataInfo getSysWarningCheckInstanceList(SysWarningCheckInstance sysWarningCheckInstance) {
        startPage();
        return getDataTable(warningCheckInstanceService.getSysWarningCheckInstanceList(sysWarningCheckInstance));
    }

    @Log(title = "告警检查项实例详情", businessType = BusinessType.SELECT)
    @ApiOperation("告警检查项实例详情")
    @GetMapping("/getSysWarningCheckInstanceDetailById/{id}")
    public AjaxResult getSysWarningCheckInstanceDetailById(@PathVariable Integer id) {
        return warningCheckInstanceService.getSysWarningCheckInstanceDetailById(id);
    }

    @Log(title = "新增告警检查项实例", businessType = BusinessType.INSERT)
    @ApiOperation("新增告警检查项实例")
    @PostMapping("/addSysWarningCheckInstance")
    public AjaxResult addSysWarningCheckInstance(@Validated @RequestBody SysWarningCheckInstance sysWarningCheckInstance) {
        return warningCheckInstanceService.addSysWarningCheckInstance(sysWarningCheckInstance);
    }

    @Log(title = "修改告警检查项实例", businessType = BusinessType.UPDATE)
    @ApiOperation("修改告警检查项实例")
    @PutMapping("/updateSysWarningCheckInstanceById")
    public AjaxResult updateSysWarningCheckInstanceById(@RequestBody SysWarningCheckInstance sysWarningCheckInstance) {
        return warningCheckInstanceService.updateSysWarningCheckInstanceById(sysWarningCheckInstance);
    }

    @Log(title = "逻辑删除告警检查项实例", businessType = BusinessType.DELETE)
    @ApiOperation("逻辑删除告警检查项实例")
    @PutMapping("/falseDeleteSysWarningCheckInstanceById/{id}")
    public AjaxResult falseDeleteSysWarningCheckInstanceById(@PathVariable Integer id) {
        return warningCheckInstanceService.falseDeleteSysWarningCheckInstanceById(id);
    }

    @Log(title = "导出告警检查项实例", businessType = BusinessType.EXPORT)
    @ApiOperation("导出告警检查项实例")
    @PostMapping("/export")
    public void export(HttpServletResponse response, @ModelAttribute SysWarningCheckInstance sysWarningCheckInstance) throws IOException {
        List<SysWarningCheckInstance> sysWarningCheckInstanceList = warningCheckInstanceService.getSysWarningCheckInstanceList(sysWarningCheckInstance);
        ExcelUtil<SysWarningCheckInstance> util = new ExcelUtil<SysWarningCheckInstance>(SysWarningCheckInstance.class);
        response.setHeader("Content-Disposition", "attachment;filename=" + URLEncoder.encode("告警检查项实例.xlsx", "UTF-8"));
        util.exportExcel(response, sysWarningCheckInstanceList, "告警检查项实例", "告警检查项实例信息");
    }


    @Log(title = "新增告警检查项作业", businessType = BusinessType.INSERT)
    @ApiOperation("新增告警检查项作业")
    @PostMapping("/addSysJob")
    public AjaxResult addSysJob(@RequestBody SysJob sysJob) throws SchedulerException, TaskException {
        return warningCheckInstanceService.addSysJob(sysJob);
    }
}

