package com.citygis.web.controller;


import com.citygis.common.annotation.Log;
import com.citygis.common.core.controller.BaseController;
import com.citygis.common.core.domain.AjaxResult;
import com.citygis.common.core.page.TableDataInfo;
import com.citygis.common.enums.BusinessType;
import com.citygis.web.domain.SysWarningExecute;
import com.citygis.web.service.ISysWarningExecuteService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;

/**
 * <p>
 * 告警执行表 前端控制器
 * </p>
 *
 * @author citygis
 * @since 2025-03-13
 */
@Api(tags = "告警配置-告警执行")
@RestController
@RequestMapping("/web/sys-warning-execute")
public class SysWarningExecuteController extends BaseController {

    @Resource
    ISysWarningExecuteService warningExecuteService;

    @Log(title = "告警执行列表", businessType = BusinessType.SELECT)
    @ApiOperation("告警执行列表")
    @GetMapping("/getSysWarningExecuteList")
    public TableDataInfo getSysWarningExecuteList(SysWarningExecute sysWarningExecute) {
        startPage();
        return getDataTable(warningExecuteService.getSysWarningExecuteList(sysWarningExecute));
    }

    @Log(title = "告警执行详情", businessType = BusinessType.SELECT)
    @ApiOperation("告警执行详情")
    @GetMapping("/getSysWarningExecuteDetailById/{id}")
    public AjaxResult getSysWarningExecuteDetailById(@PathVariable Long id) {
        return warningExecuteService.getSysWarningExecuteDetailById(id);
    }

    @Log(title = "新增告警执行", businessType = BusinessType.INSERT)
    @ApiOperation("新增告警执行")
    @PostMapping("/addSysWarningExecute")
    public AjaxResult addSysWarningExecute(@Validated @RequestBody SysWarningExecute sysWarningExecute) {
        return warningExecuteService.addSysWarningExecute(sysWarningExecute);
    }

    @Log(title = "修改告警执行", businessType = BusinessType.UPDATE)
    @ApiOperation("修改告警执行")
    @PutMapping("/updateSysWarningExecuteById")
    public AjaxResult updateSysWarningExecuteById(@RequestBody SysWarningExecute sysWarningExecute) {
        return warningExecuteService.updateSysWarningExecuteById(sysWarningExecute);
    }

    @Log(title = "逻辑删除告警执行", businessType = BusinessType.DELETE)
    @ApiOperation("逻辑删除告警执行")
    @PutMapping("/falseDeleteSysWarningExecuteById/{id}")
    public AjaxResult falseDeleteSysWarningExecuteById(@PathVariable Long id) {
        return warningExecuteService.falseDeleteSysWarningExecuteById(id);
    }
}

