package com.citygis.web.controller;


import com.citygis.common.annotation.Log;
import com.citygis.common.core.controller.BaseController;
import com.citygis.common.core.domain.AjaxResult;
import com.citygis.common.core.page.TableDataInfo;
import com.citygis.common.enums.BusinessType;
import com.citygis.common.utils.poi.ExcelUtil;
import com.citygis.web.domain.SysWarningLog;
import com.citygis.web.service.ISysWarningLogService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.io.UnsupportedEncodingException;
import java.net.URLEncoder;
import java.util.List;

/**
 * <p>
 * 系统告警日志表 前端控制器
 * </p>
 *
 * @author citygis
 * @since 2025-03-13
 */
@Api(tags = "告警配置-系统告警日志")
@RestController
@RequestMapping("/web/sys-warning-log")
public class SysWarningLogController extends BaseController {

    @Resource
    ISysWarningLogService warningLogService;

    @Log(title = "新增系统告警日志", businessType = BusinessType.INSERT)
    @ApiOperation("新增系统告警日志")
    @PostMapping("/addSysWarningLog")
    public AjaxResult addSysWarningLog(@Validated @RequestBody SysWarningLog sysWarningLog) {
        return warningLogService.addSysWarningLog(sysWarningLog);
    }

    @Log(title = "系统告警日志列表", businessType = BusinessType.SELECT)
    @ApiOperation("系统告警日志列表")
    @GetMapping("/getSysWarningLogList")
    public TableDataInfo getSysWarningLogList(SysWarningLog sysWarningLog) {
        startPage();
        return getDataTable(warningLogService.getSysWarningLogList(sysWarningLog));
    }

    @Log(title = "系统告警日志详情", businessType = BusinessType.SELECT)
    @ApiOperation("系统告警日志详情")
    @GetMapping("/getSysWarningLogDetailById/{id}")
    public AjaxResult getSysWarningLogDetailById(@PathVariable Long id) {
        return warningLogService.getSysWarningLogDetailById(id);
    }

    @Log(title = "导出系统告警日志", businessType = BusinessType.EXPORT)
    @ApiOperation("导出系统告警日志")
    @PostMapping("/export")
    public void export(HttpServletResponse response, @ModelAttribute SysWarningLog sysWarningLog) throws UnsupportedEncodingException {
        List<SysWarningLog> sysWarningLogList = warningLogService.getSysWarningLogList(sysWarningLog);
        ExcelUtil<SysWarningLog> util = new ExcelUtil<SysWarningLog>(SysWarningLog.class);
        response.setHeader("Content-Disposition", "attachment;filename=" + URLEncoder.encode("系统告警日志.xlsx", "UTF-8"));
        util.exportExcel(response, sysWarningLogList, "系统告警日志", "系统告警日志信息");
    }

}

