package com.citygis.web.controller;


import com.citygis.common.annotation.Log;
import com.citygis.common.core.controller.BaseController;
import com.citygis.common.core.domain.AjaxResult;
import com.citygis.common.core.page.TableDataInfo;
import com.citygis.common.enums.BusinessType;
import com.citygis.web.domain.SysWarningUserGroup;
import com.citygis.web.service.ISysWarningUserGroupService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;

/**
 * <p>
 * 告警用户组表 前端控制器
 * </p>
 *
 * @author citygis
 * @since 2025-03-13
 */
@Api(tags = "告警配置-告警用户组")
@RestController
@RequestMapping("/web/sys-warning-user-group")
public class SysWarningUserGroupController extends BaseController {

    @Resource
    ISysWarningUserGroupService warningUserGroupService;

    @Log(title = "告警用户组列表", businessType = BusinessType.SELECT)
    @ApiOperation("告警用户组列表")
    @GetMapping("/getSysWarningUserGroupList")
    public TableDataInfo getSysWarningUserGroupList(SysWarningUserGroup sysWarningUserGroup) {
        startPage();
        return getDataTable(warningUserGroupService.getSysWarningUserGroupList(sysWarningUserGroup));
    }

    @Log(title = "告警用户组详情", businessType = BusinessType.SELECT)
    @ApiOperation("告警用户组详情")
    @GetMapping("/getSysWarningUserGroupDetailById/{id}")
    public SysWarningUserGroup getSysWarningUserGroupDetailById(@PathVariable Long id) {
        return warningUserGroupService.getById(id);
    }

    @Log(title = "新增告警用户组", businessType = BusinessType.INSERT)
    @ApiOperation("新增告警用户组")
    @PostMapping("/addSysWarningUserGroup")
    public AjaxResult addSysWarningUserGroup(@Validated @RequestBody SysWarningUserGroup sysWarningUserGroup) {
        return warningUserGroupService.addSysWarningUserGroup(sysWarningUserGroup);
    }

    @Log(title = "修改告警用户组", businessType = BusinessType.UPDATE)
    @ApiOperation("修改告警用户组")
    @PutMapping("/updateSysWarningUserGroupById")
    public AjaxResult updateSysWarningUserGroupById(@RequestBody SysWarningUserGroup sysWarningUserGroup) {
        return warningUserGroupService.updateSysWarningUserGroupById(sysWarningUserGroup);
    }

    @Log(title = "逻辑删除告警用户组", businessType = BusinessType.DELETE)
    @ApiOperation("逻辑删除告警用户组")
    @PutMapping("/falseDeleteSysWarningUserGroupById/{id}")
    public AjaxResult falseDeleteSysWarningUserGroupById(@PathVariable Long id) {
        return warningUserGroupService.falseDeleteSysWarningUserGroupById(id);
    }
}

