package com.citygis.web.domain;

import cn.hutool.core.date.DatePattern;
import cn.hutool.core.date.DateUtil;
import com.citygis.common.entity.KafkaEntity;
import com.citygis.framework.aspectj.KafkaPushAspect;
import com.fasterxml.jackson.annotation.JsonFormat;
import lombok.Data;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.validation.constraints.NotEmpty;
import java.util.Date;

/**
 * @Name KafkaPushDTO
 * @Version 1.0
 * @Date 2025-02-21 15:10:09
 * @Author harri
 * @Description:
 */

@Data
public class KafkaPushDTO extends KafkaEntity {

    private static final Logger log = LoggerFactory.getLogger(KafkaPushAspect.class);

    /**
     * 告警对象
     * @Description 产生告警的对象（middb和jkcloud业务视图）
     * @author harri
     * @version 1.0
     */
    @NotEmpty(message = "targetName is required")
    private String targetName;

    /**
     * 检查项
     * @Description 告警规则项（middb数据比jkcloud数据少n条）
     * @author harri
     * @version 1.0
     */
    @NotEmpty(message = "check is required")
    private String check;

    /**
     * 告警描述
     * @Description 告警详细描述
     * @author harri
     * @version 1.0
     */
    @NotEmpty(message = "description is required")
    private String description;

    /**
     * 告警等级
     * @Description 告警等级（0 正常，1 提示，2 次要，3 严重，4 灾难）
     * @author harri
     * @version 1.0
     */
    @NotEmpty(message = "level is required")
    private String level;

    /**
     * 告警时间
     * @Instance 2025-03-12 14:08:16
     * @author harri
     * @version 1.0
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private String createTime;

    /**
     * 告警标识符
     * @Instance liutongyi
     * @author harri
     * @version 1.0
     */
    private String alertId;

    public KafkaPushDTO() {
        try {
            this.createTime = DateUtil.format(new Date(), DatePattern.NORM_DATETIME_PATTERN);
            this.alertId = "liutongyi";
        } catch (Exception e) {
            // 记录日志并设置一个默认值
            this.createTime = "1970-01-01 00:00:00";
            log.error("Failed to format date: " + e.getMessage());
        }
    }

    public KafkaPushDTO(String createTime, String alertId) {
        this.createTime = createTime;
        this.alertId = alertId;
    }
}
