package com.citygis.web.service.impl;

import cn.hutool.core.lang.Snowflake;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.citygis.common.annotation.DataScope;
import com.citygis.common.core.domain.AjaxResult;
import com.citygis.web.domain.SysWarningChannel;
import com.citygis.web.mapper.SysWarningChannelMapper;
import com.citygis.web.service.ISysWarningChannelService;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Date;
import java.util.List;

import static org.apache.commons.lang3.SystemUtils.getUserName;

/**
 * <p>
 * 告警渠道表 服务实现类
 * </p>
 *
 * @author citygis
 * @since 2025-03-13
 */
@Service
public class SysWarningChannelServiceImpl extends ServiceImpl<SysWarningChannelMapper, SysWarningChannel> implements ISysWarningChannelService {

    @Override
    @DataScope(deptAlias = "swc", userAlias = "swc")
    public List<SysWarningChannel> getSysWarningChannelList(SysWarningChannel sysWarningChannel) {
        return baseMapper.getSysWarningChannelList(sysWarningChannel);
    }

    @Override
    public AjaxResult getSysWarningChannelDetailById(Long id) {
        SysWarningChannel byId = this.getById(id);
        if (byId == null) {
            return AjaxResult.success("查询失败");
        }
        return AjaxResult.success(byId);
    }

    @Transactional
    @Override
    public AjaxResult addSysWarningChannel(SysWarningChannel sysWarningChannel) {
        Snowflake snowflake = new Snowflake(1, 1);

        sysWarningChannel.setAlertId(snowflake.nextId());
        sysWarningChannel.setCreateBy(getUserName());
        sysWarningChannel.setUserId(sysWarningChannel.getUserId());
        sysWarningChannel.setDeptId(sysWarningChannel.getDeptId());
        sysWarningChannel.setCreateTime(new Date());

        boolean b = this.save(sysWarningChannel);
        if (b) {
            return AjaxResult.success("添加成功");
        } else {
            return AjaxResult.success("添加失败");
        }
    }

    @Transactional
    @Override
    public AjaxResult updateSysWarningChannelById(SysWarningChannel sysWarningChannel) {
        sysWarningChannel.setUpdateBy(getUserName());
        sysWarningChannel.setUpdateTime(new Date());

        boolean b = this.updateById(sysWarningChannel);
        if (b) {
            return AjaxResult.success("修改成功");
        } else {
            return AjaxResult.success("修改失败");
        }
    }

    @Transactional
    @Override
    public AjaxResult falseDeleteSysWarningChannelById(Long id) {
        SysWarningChannel sysWarningChannel = new SysWarningChannel();
        sysWarningChannel.setAlertId(id);
        sysWarningChannel.setIsDel(1);

        boolean b = this.updateById(sysWarningChannel);
        if (b) {
            return AjaxResult.success("删除成功");
        } else {
            return AjaxResult.success("删除失败");
        }
    }
}
