package com.citygis.web.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.citygis.common.annotation.DataScope;
import com.citygis.common.core.domain.AjaxResult;
import com.citygis.common.exception.job.TaskException;
import com.citygis.quartz.domain.SysJob;
import com.citygis.quartz.mapper.SysJobMapper;
import com.citygis.quartz.util.ScheduleUtils;
import com.citygis.web.domain.SysWarningCheckInstance;
import com.citygis.web.mapper.SysWarningCheckInstanceMapper;
import com.citygis.web.service.ISysWarningCheckInstanceService;
import org.quartz.Scheduler;
import org.quartz.SchedulerException;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;

import static com.citygis.common.utils.SecurityUtils.getDeptId;
import static com.citygis.common.utils.SecurityUtils.getUserId;
import static org.apache.commons.lang3.SystemUtils.getUserName;

/**
 * <p>
 * 告警检查项实例表 服务实现类
 * </p>
 *
 * @author citygis
 * @since 2025-03-13
 */
@Service
public class SysWarningCheckInstanceServiceImpl extends ServiceImpl<SysWarningCheckInstanceMapper, SysWarningCheckInstance> implements ISysWarningCheckInstanceService {

    @Resource
    SysJobMapper jobMapper;

    @Resource
    Scheduler scheduler;

    @DataScope(deptAlias = "swci", userAlias = "swci")
    @Override
    public List<SysWarningCheckInstance> getSysWarningCheckInstanceList(SysWarningCheckInstance sysWarningCheckInstance) {
        return baseMapper.getSysWarningCheckInstanceList(sysWarningCheckInstance);
    }

    @Override
    public AjaxResult getSysWarningCheckInstanceDetailById(Integer id) {
        SysWarningCheckInstance byId = this.getById(id);
        if (byId == null) {
            return AjaxResult.success("查询失败");
        }
        return AjaxResult.success(byId);
    }

    @Transactional
    @Override
    public AjaxResult addSysWarningCheckInstance(SysWarningCheckInstance sysWarningCheckInstance) {

        sysWarningCheckInstance.setCreateBy(getUserName());
        sysWarningCheckInstance.setUserId(getUserId());
        sysWarningCheckInstance.setDeptId(getDeptId());
        sysWarningCheckInstance.setCreateTime(new Date());

        boolean b = this.save(sysWarningCheckInstance);
        if (b) {
            return AjaxResult.success("添加成功");
        } else {
            return AjaxResult.success("添加失败");
        }

    }

    @Transactional
    @Override
    public AjaxResult updateSysWarningCheckInstanceById(SysWarningCheckInstance sysWarningCheckInstance) {

        sysWarningCheckInstance.setUpdateBy(getUserName());
        sysWarningCheckInstance.setUpdateTime(new Date());

        boolean b = this.updateById(sysWarningCheckInstance);
        if (b) {
            return AjaxResult.success("修改成功");
        } else {
            return AjaxResult.success("修改失败");
        }
    }

    @Transactional
    @Override
    public AjaxResult falseDeleteSysWarningCheckInstanceById(Integer id) {
        SysWarningCheckInstance sysWarningCheckInstance = new SysWarningCheckInstance();
        sysWarningCheckInstance.setCheckId(id);
        sysWarningCheckInstance.setIsDel(1);

        boolean b = this.updateById(sysWarningCheckInstance);
        if (b) {
            return AjaxResult.success("删除成功");
        } else {
            return AjaxResult.success("删除失败");
        }
    }

    @Transactional
    @Override
    public AjaxResult addSysJob(SysJob sysJob) throws SchedulerException, TaskException {
        SysWarningCheckInstance warningCheckInstance = new SysWarningCheckInstance();

        String invokeTarget = sysJob.getInvokeTarget();

        warningCheckInstance.setCheckId(Integer.valueOf(invokeTarget));

        invokeTarget = "alarmTask.alarm(" + invokeTarget + ")";

        sysJob.setInvokeTarget(invokeTarget);

        int rows = jobMapper.insertJob(sysJob);
        if (rows > 0) {
            ScheduleUtils.createScheduleJob(scheduler, sysJob);
        }

        warningCheckInstance.setJobId(sysJob.getJobId());

        this.updateById(warningCheckInstance);

        return AjaxResult.success("添加成功");

    }
}
