package com.citygis.web.service.impl;

import cn.hutool.core.lang.Snowflake;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.citygis.common.annotation.DataScope;
import com.citygis.common.core.domain.AjaxResult;
import com.citygis.web.domain.SysWarningExecute;
import com.citygis.web.mapper.SysWarningExecuteMapper;
import com.citygis.web.service.ISysWarningExecuteService;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Date;
import java.util.List;

import static com.citygis.common.utils.SecurityUtils.getDeptId;
import static com.citygis.common.utils.SecurityUtils.getUserId;
import static org.apache.commons.lang3.SystemUtils.getUserName;

/**
 * <p>
 * 告警执行表 服务实现类
 * </p>
 *
 * @author citygis
 * @since 2025-03-13
 */
@Service
public class SysWarningExecuteServiceImpl extends ServiceImpl<SysWarningExecuteMapper, SysWarningExecute> implements ISysWarningExecuteService {

    @DataScope(deptAlias = "swe", userAlias = "swe")
    @Override
    public List<SysWarningExecute> getSysWarningExecuteList(SysWarningExecute sysWarningExecute) {
        return baseMapper.getSysWarningExecuteList(sysWarningExecute);
    }

    @Override
    public AjaxResult getSysWarningExecuteDetailById(Long id) {
        SysWarningExecute byId = this.getById(id);
        if (byId == null) {
            return AjaxResult.success("查询失败");
        }
        return AjaxResult.success(byId);
    }

    @Transactional
    @Override
    public AjaxResult addSysWarningExecute(SysWarningExecute sysWarningExecute) {
        Snowflake snowflake = new Snowflake(1, 1);

        sysWarningExecute.setExecuteId(snowflake.nextId());
        sysWarningExecute.setCreateBy(getUserName());
        sysWarningExecute.setUserId(getUserId());
        sysWarningExecute.setDeptId(getDeptId());
        sysWarningExecute.setCreateTime(new Date());

        boolean b = this.save(sysWarningExecute);
        if (b) {
            return AjaxResult.success("添加成功");
        } else {
            return AjaxResult.success("添加失败");
        }
    }

    @Transactional
    @Override
    public AjaxResult updateSysWarningExecuteById(SysWarningExecute sysWarningExecute) {
        sysWarningExecute.setUpdateBy(getUserName());
        sysWarningExecute.setUpdateTime(new Date());

        boolean b = this.updateById(sysWarningExecute);
        if (b) {
            return AjaxResult.success("修改成功");
        } else {
            return AjaxResult.success("修改失败");
        }
    }

    @Transactional
    @Override
    public AjaxResult falseDeleteSysWarningExecuteById(Long id) {
        SysWarningExecute sysWarningExecute = new SysWarningExecute();
        sysWarningExecute.setExecuteId(id);
        sysWarningExecute.setIsDel(1);

        boolean b = this.updateById(sysWarningExecute);
        if (b) {
            return AjaxResult.success("删除成功");
        } else {
            return AjaxResult.success("删除失败");
        }
    }
}
