package com.citygis.web.service.impl;

import cn.hutool.core.lang.Snowflake;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.citygis.common.annotation.DataScope;
import com.citygis.common.core.domain.AjaxResult;
import com.citygis.web.domain.SysWarningUserGroup;
import com.citygis.web.mapper.SysWarningUserGroupMapper;
import com.citygis.web.service.ISysWarningUserGroupService;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Date;
import java.util.List;

import static com.citygis.common.utils.SecurityUtils.getDeptId;
import static com.citygis.common.utils.SecurityUtils.getUserId;
import static org.apache.commons.lang3.SystemUtils.getUserName;

/**
 * <p>
 * 告警用户组表 服务实现类
 * </p>
 *
 * @author citygis
 * @since 2025-03-13
 */
@Service
public class SysWarningUserGroupServiceImpl extends ServiceImpl<SysWarningUserGroupMapper, SysWarningUserGroup> implements ISysWarningUserGroupService {

    @DataScope(deptAlias = "twug", userAlias = "twug")
    @Override
    public List<SysWarningUserGroup> getSysWarningUserGroupList(SysWarningUserGroup sysWarningUserGroup) {
        return baseMapper.getSysWarningUserGroupList(sysWarningUserGroup);
    }

    @Override
    public AjaxResult getSysWarningUserGroupDetailById(Long id) {
        SysWarningUserGroup byId = this.getById(id);
        if (byId == null) {
            return AjaxResult.success("查询失败");
        }
        return AjaxResult.success(byId);
    }

    @Transactional
    @Override
    public AjaxResult addSysWarningUserGroup(SysWarningUserGroup sysWarningUserGroup) {
        Snowflake snowflake = new Snowflake(1, 1);

        sysWarningUserGroup.setGroupId(snowflake.nextId());
        sysWarningUserGroup.setUserName(getUserName());
        sysWarningUserGroup.setUserId(getUserId());
        sysWarningUserGroup.setDeptId(getDeptId());
        sysWarningUserGroup.setCreateTime(new Date());

        boolean b = this.save(sysWarningUserGroup);
        if (b) {
            return AjaxResult.success("添加成功");
        } else {
            return AjaxResult.success("添加失败");
        }
    }

    @Transactional
    @Override
    public AjaxResult updateSysWarningUserGroupById(SysWarningUserGroup sysWarningUserGroup) {
        sysWarningUserGroup.setUpdateBy(getUserName());
        sysWarningUserGroup.setUpdateTime(new Date());

        boolean b = this.updateById(sysWarningUserGroup);

        if (b) {
            return AjaxResult.success("修改成功");
        } else {
            return AjaxResult.success("修改失败");
        }
    }

    @Transactional
    @Override
    public AjaxResult falseDeleteSysWarningUserGroupById(Long id) {
        SysWarningUserGroup sysWarningUserGroup = new SysWarningUserGroup();
        sysWarningUserGroup.setGroupId(id);
        sysWarningUserGroup.setIsDel(1);

        boolean b = this.updateById(sysWarningUserGroup);
        if (b) {
            return AjaxResult.success("删除成功");
        } else {
            return AjaxResult.success("删除失败");
        }
    }
}
