package com.citygis.web.task;

import cn.hutool.core.lang.Snowflake;
import cn.hutool.core.util.IdUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.citygis.web.domain.TabIp;
import com.citygis.web.domain.TabIpResult;
import com.citygis.web.service.ITabIpResultService;
import com.citygis.web.service.ITabIpService;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.io.IOException;
import java.net.InetAddress;
import java.net.InetSocketAddress;
import java.net.Socket;
import java.net.SocketAddress;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * @Author: zyl
 * @CreateTime: 2025-03-07
 * @Description: ip监测
 * @Version: 1.0
 */
@Component("ipListenTask")
public class IpListenTask {

    @Resource
    ITabIpService tabIpService;

    @Resource
    ITabIpResultService tabIpResultService;

    public void insertTabIpResult() {
        List<TabIpResult> tabIpResultList = new ArrayList<>();

        Snowflake snowflake = IdUtil.getSnowflake(1, 1);
        Socket socket = new Socket();


        LambdaQueryWrapper<TabIp> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(TabIp::getIsApply, 1);
        List<TabIp> list = tabIpService.list(queryWrapper);

        list.forEach(tabIp -> {
            TabIpResult tabIpResult = new TabIpResult();

            tabIpResult.setId(snowflake.nextId());

            String ip = tabIp.getIp();
            Integer port = tabIp.getPort();

            tabIpResult.setIp(ip);
            tabIpResult.setPort(port);

            if (port != null) {
                SocketAddress socketAddress = new InetSocketAddress(ip, port);
                try {
                    socket.connect(socketAddress, 3000); // 超过3秒则视为失败
                    tabIpResult.setResult("true");
                    socket.close();

                } catch (IOException e) {
                    tabIpResult.setResult("false");
                }
            } else {
                InetAddress inetAddress = null;
                try {
                    inetAddress = InetAddress.getByName(ip);
                    tabIpResult.setResult(String.valueOf(inetAddress.isReachable(3000)));
                } catch (IOException e) {
                    throw new RuntimeException(e);
                }


            }
            tabIpResult.setDescription(tabIp.getDescription());
            tabIpResult.setCreateTime(new Date());
            tabIpResultList.add(tabIpResult);
        });

        tabIpResultService.saveBatch(tabIpResultList);
    }

}
