package com.citygis.web.task;

import cn.hutool.core.lang.Snowflake;
import cn.hutool.core.util.IdUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.citygis.common.annotation.DataSource;
import com.citygis.common.enums.DataSourceType;
import com.citygis.web.domain.TabSystemMsg;
import com.citygis.web.domain.TabTopicListenResult;
import com.citygis.web.service.ITabSystemMsgService;
import com.citygis.web.service.ITabTopicListenResultService;
import org.apache.kafka.clients.admin.AdminClient;
import org.apache.kafka.clients.admin.DescribeTopicsResult;
import org.apache.kafka.clients.admin.TopicDescription;
import org.apache.kafka.common.KafkaFuture;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.*;
import java.util.concurrent.ExecutionException;

/**
 * @Author: zyl
 * @CreateTime: 2025-03-07
 * @Description: topic监听
 * @Version: 1.0
 */
@Component("topicListenTask")
@DataSource(DataSourceType.SLAVE)
public class TopicListenTask {

    @Value("${kafka.ip}")
    public String ip;

    @Resource
    ITabSystemMsgService tabSystemMsgService;

    @Resource
    ITabTopicListenResultService tabTopicListenResultService;

    public void insertTabTopicListenResult() {

        List<TabTopicListenResult> tabTopicListenResultArrayList = new ArrayList<>();

        Properties props = new Properties();
        props.put("bootstrap.servers", ip);

        LambdaQueryWrapper<TabSystemMsg> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(TabSystemMsg::getAccessManner, "kafka");
        queryWrapper.eq(TabSystemMsg::getIsApply, 1);
        List<TabSystemMsg> list = tabSystemMsgService.list(queryWrapper);

        Snowflake snowflake = IdUtil.getSnowflake(1, 1);
        for (TabSystemMsg tabSystemMsg : list) {
            String topic = tabSystemMsg.getTableEnglishName();

            TabTopicListenResult tabTopicListenResult = new TabTopicListenResult();

            tabTopicListenResult.setId(snowflake.nextId());
            tabTopicListenResult.setTopic(topic);
            tabTopicListenResult.setCreateTime(new Date());

            try (AdminClient adminClient = AdminClient.create(props)) {
                DescribeTopicsResult describeTopicsResult = adminClient.describeTopics(Collections.singletonList(topic));
                KafkaFuture<TopicDescription> future = describeTopicsResult.values().get(topic);
                TopicDescription topicDescription = future.get();
                tabTopicListenResult.setState("true");
            } catch (ExecutionException | InterruptedException e) {
                System.err.println(e.getMessage());
                tabTopicListenResult.setState("false");
            }
            tabTopicListenResultArrayList.add(tabTopicListenResult);
        }

        tabTopicListenResultService.saveBatch(tabTopicListenResultArrayList);

    }

}
