package com.citygis.web.task;

import cn.hutool.core.lang.Snowflake;
import cn.hutool.core.util.IdUtil;
import com.citygis.common.annotation.DataSource;
import com.citygis.common.enums.DataSourceType;
import com.citygis.web.domain.SlaveTabUrl;
import com.citygis.web.domain.TabUrlListenResult;
import com.citygis.web.mapper.SlaveDataBaseMapper;
import com.citygis.web.service.ITabUrlListenResultService;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.io.IOException;
import java.net.HttpURLConnection;
import java.net.Socket;
import java.net.URL;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * @Author: zyl
 * @CreateTime: 2025-03-07
 * @Description: 监听url
 * @Version: 1.0
 */
@Component("urlListeningTask")
@DataSource(DataSourceType.SLAVE)
public class UrlListeningTask {

    @Resource
    SlaveDataBaseMapper slaveDataBaseMapper;

    @Resource
    ITabUrlListenResultService tabUrlListenResutlService;

    /**
     * 检查所有URL服务是否可用
     * 所有URL均返回HTTP 200时视为可用，否则不可用
     *
     * @return 全部可用返回true，否则false
     */
    public void isServiceAvailable() {

        List<SlaveTabUrl> slaveTabUrlList = slaveDataBaseMapper.getSlaveTabUrl();

        List<TabUrlListenResult> tabIpResultList = new ArrayList<>();

        Snowflake snowflake = IdUtil.getSnowflake(1, 1);
        Socket socket = new Socket();

        for (SlaveTabUrl slaveTabUrl : slaveTabUrlList) {
            HttpURLConnection connection = null;

            TabUrlListenResult tabIpResult = new TabUrlListenResult();

            try {
                String urlString = slaveTabUrl.getUrl();
                String requestMethodType = slaveTabUrl.getRequestMethodType().toUpperCase();

                URL url = new URL(urlString);
                connection = (HttpURLConnection) url.openConnection();

                // 设置通用参数
                connection.setConnectTimeout(5000);
                connection.setReadTimeout(5000);
                connection.setInstanceFollowRedirects(false); // 通常不自动重定向以准确获取状态码

                // 设置请求方法
                connection.setRequestMethod(requestMethodType);

                // 处理POST请求
                if ("POST".equals(requestMethodType)) {
                    connection.setDoOutput(true);
                    connection.setRequestProperty("Content-Type", "application/json");
                    // 如需发送请求体，可在此写入
                    // try (OutputStream os = connection.getOutputStream()) {
                    //     os.write("{}".getBytes(StandardCharsets.UTF_8));
                    // }
                }

                // 获取响应码（HEAD请求可能更高效，但需服务器支持）
                int responseCode = connection.getResponseCode();

                // 检查是否需要跟随重定向（可选）
                if (connection.getInstanceFollowRedirects() &&
                        (responseCode == HttpURLConnection.HTTP_MOVED_PERM ||
                                responseCode == HttpURLConnection.HTTP_MOVED_TEMP)) {
                    String newUrl = connection.getHeaderField("Location");
                    // 这里可以添加递归或循环处理重定向逻辑
                }

                tabIpResult.setId(snowflake.nextId());
                tabIpResult.setUrl(slaveTabUrl.getUrl());

                if (responseCode != HttpURLConnection.HTTP_OK) {
                    tabIpResult.setResult("false");

                } else {
                    tabIpResult.setResult("true");
                }
                tabIpResult.setCreateTime(new Date());
                tabIpResultList.add(tabIpResult);

            } catch (IOException e) {
                e.printStackTrace(); // 发生异常视为不可用
            } finally {
                if (connection != null) {
                    connection.disconnect(); // 确保每个连接都被关闭
                }
            }
        }

        tabUrlListenResutlService.saveBatch(tabIpResultList);

    }

}
