package com.citygis.web.task;

import com.alibaba.excel.EasyExcel;
import com.alibaba.excel.util.MapUtils;
import com.citygis.common.annotation.DataSource;
import com.citygis.common.enums.DataSourceType;
import com.citygis.framework.datasource.DynamicDataSourceContextHolder;
import com.citygis.web.domain.TabAccessTableMsg;
import com.citygis.web.domain.TabFileInfo;
import com.citygis.web.domain.TabSystemMsg;
import com.citygis.web.mapper.TabSystemMsgMapper;
import com.citygis.web.service.ITabFileInfoService;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.time.DayOfWeek;
import java.time.LocalDate;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * @Author: zyl
 * @CreateTime: 2025-03-06
 * @Description: 周报生成
 * @Version: 1.0
 */
@Component("weekReportTask")
@DataSource(DataSourceType.MASTER)
public class WeekReportTask {

    @Value("${weekReport.filepath}")
    private String weekReportFilePath;

    @Value("${weekReport.templateFilePath}")
    private String templateFilePath;

    @Resource
    TabSystemMsgMapper tabSystemMsgMapper;

    @Resource
    ITabFileInfoService tabFileInfoService;

    public void weekReport() {

        // 获取当前日期
        LocalDate today = LocalDate.now();

        // 获取上周的同一日
        LocalDate lastWeek = today.minusWeeks(1);

        // 获取上周周一的日期
        String lastMonday = lastWeek.with(DayOfWeek.MONDAY).toString();

        // 获取上周周日的日期
        String lastSunday = lastWeek.with(DayOfWeek.SUNDAY).toString();

        List<TabSystemMsg> tabSystemMsgList = getTabSystemMsgList();

        List<TabAccessTableMsg> count = new ArrayList<>();

        count.addAll(getTabAccessTableMsgList(lastMonday, lastSunday));
        count.addAll(getJkcloudCount(lastMonday, lastSunday));

        Map<String, Object> map = MapUtils.newHashMap();

        tabSystemMsgList.forEach(tabSystemMsgReport -> {
            count.forEach(tabAccessTableMsg1 -> {
                if (tabAccessTableMsg1.getTableName().equals(tabSystemMsgReport.getTableEnglishName())) {
                    map.put(tabAccessTableMsg1.getTableName(), tabAccessTableMsg1.getCount());
                }
            });
        });

        // 设置文件保存路径
        String filePath = weekReportFilePath + "疾控周报" + lastMonday + "-" + lastSunday + ".xlsx";

        EasyExcel.write(filePath).withTemplate(templateFilePath).sheet().doFill(map);

        saveTabFileInfo(filePath);
    }

    public List<TabSystemMsg> getTabSystemMsgList() {
        DynamicDataSourceContextHolder.setDataSourceType(DataSourceType.SLAVE.name());
        List<TabSystemMsg> list = tabSystemMsgMapper.getTabSystemMsgList(new TabSystemMsg());
        DynamicDataSourceContextHolder.clearDataSourceType();
        return list;
    }

    public List<TabAccessTableMsg> getTabAccessTableMsgList(String startTime, String endTime) {
        DynamicDataSourceContextHolder.setDataSourceType(DataSourceType.SLAVE.name());
        List<TabAccessTableMsg> tabAccessTableMsgList = tabSystemMsgMapper.getTabAccessTableMsgList(startTime, endTime);
        DynamicDataSourceContextHolder.clearDataSourceType();
        return tabAccessTableMsgList;
    }


    public List<TabAccessTableMsg> getJkcloudCount(String startTime, String endTime) {
        DynamicDataSourceContextHolder.setDataSourceType(DataSourceType.SLAVE_TWO.name());
        List<TabAccessTableMsg> jkcloudCount = tabSystemMsgMapper.getJkcloudCount(startTime, endTime);
        DynamicDataSourceContextHolder.clearDataSourceType();
        return jkcloudCount;
    }

    private void saveTabFileInfo(String filePath) {
        //保存到主库，手动切换数据源
//        DynamicDataSourceContextHolder.setDataSourceType(DataSourceType.MASTER.name());
        TabFileInfo tabFileInfo = new TabFileInfo();
        tabFileInfo.setFileName(filePath.substring(filePath.lastIndexOf("\\") + 1));
        tabFileInfo.setFilePath(filePath);
        tabFileInfo.setCreateTime(new Date());
        tabFileInfo.setCreateBy("system");
        tabFileInfo.setSystemType("疾控周报");
        tabFileInfoService.save(tabFileInfo);
//        DynamicDataSourceContextHolder.clearDataSourceType();
    }

}
